# Projet "Forum"

## Lancement du projet

    mvn jetty:run

## Partie 1

On veut ajouter une fonction d'édition des messages déjà écrits.

Elle ressemblera à la fonction de création de messages, à quelques points près :

- le message a déjà un identifiant
- les données sont pré-remplies à partir du message à éditer.

Concrètement :

- le `doGet` de la servlet récupèrera l'identifiant du message comme paramètre ; on appellera l'édition par une url de la forme `/message/editer?id=3` pour éditer le message numéro 3 ;
- le formulaire d'édition, contrairement au formulaire de création, devra aussi enregistrer l'identifiant du message, dont on aura besoin pour savoir quel message il faut modifier. Le plus simple est d'utiliser un champ caché :
        
    ~~~html
    <input type="hidden" name="id" value="${form.id}"/>
    ~~~

    à défaut, on pourrait utiliser un champ affiché, mais non éditable.

## Partie 2

On veut maintenant ajouter la notion d'auteur au message. On a déjà configuré les classes nécessaires pour gérer le login et le mot de passe d'un utilisateur (dans la réalité, le mot de passe serait "haché" (par exemple avec BCrypt)).

### Observation

Regardez le code :

- de la classe `UtilisateurHelper` ;
- du contrôleur `Login` ;
- du contrôleur `Logout` ; 

### Question 1

Ajoutez à la page `list.jsp` deux éléments :

- si l'utilisateur n'est pas connecté, on veut un lien qui envoie vers la page de login ;
- si l'utilisateur est connecté, ajouté un formulaire en mode `POST` qui exécute le logout.

On peut éventuellement faire de cette partie une jsp à part, et inclure systématiquement cette partie aux diverses pages, en utilisant :

~~~jsp
    <%@include file="head.jsp" %>
~~~

### Question 2

Limitez la fonctionnalité de *création* de message aux utilisateurs connectés. Un utilisateur non connecté sera envoyé sur la page de login.

### Question 3

Maintenant que pour créer un message, il faut être identifié, modifiez la classe des messages pour qu'un message ait un auteur.

Dans la réalité, on séparerait le couple login/password et login/signature/informations diverses en deux classes, pour éviter le risque de conserver des informations sensibles en mémoire, mais ça n'est pas notre problème.

Modifiez la méthode de création de message pour que le message soit enregistré au nom de son auteur (ajoutez l'auteur comme propriété de l'objet `Message` du modèle), et modifiez le code d'affichage pour afficher la signature de l'auteur.

Il faudrait évidemment faire la même modification pour l'édition de message.



